@@ -2,11 +2,12 @@
 """
 Helper methods to download and open IIIF images, and manage polygons.
 """
-
 import os
 from collections import namedtuple
 from io import BytesIO
 from math import ceil
+from pathlib import Path
+from typing import TYPE_CHECKING, List, Optional, Union
 
 import requests
 from PIL import Image
@@ -21,28 +22,38 @@ from tenacity import (
 
 from arkindex_worker import logger
 
+# Avoid circular imports error when type checking
+if TYPE_CHECKING:
+    from arkindex_worker.cache import CachedElement
+    from arkindex_worker.models import Element
+
 # See http://docs.python-requests.org/en/master/user/advanced/#timeouts
 DOWNLOAD_TIMEOUT = (30, 60)
 
 BoundingBox = namedtuple("BoundingBox", ["x", "y", "width", "height"])
 
 
-def open_image(path, mode="RGB", rotation_angle=0, mirrored=False):
+def open_image(
+    path: Union[str, Path],
+    mode: Optional[str] = "RGB",
+    rotation_angle: Optional[int] = 0,
+    mirrored: Optional[bool] = False,
+) -> Image:
     """
     Open an image from a path or a URL.
 
-    .. warning:: Prefer :meth:`Element.open_image` whenever possible.
+    Warns:
+    Prefer [arkindex_worker.models.Element.open_image][] whenever possible.
 
-    :param path str: Path or URL to open the image from.
+    :param path: Path or URL to open the image from.
        This parameter will be interpreted as a URL when it has a `http` or `https` scheme
        and no file exist with this path locally.
-    :param mode str: Pillow mode for the image. See `the Pillow documentation
-        <https://pillow.readthedocs.io/en/stable/handbook/concepts.html#modes>`_.
-    :param int rotation_angle: Rotation angle to apply to the image, in degrees.
+    :param mode: Pillow mode for the image. See [the Pillow documentation](https://pillow.readthedocs.io/en/stable/handbook/concepts.html#modes).
+    :param rotation_angle: Rotation angle to apply to the image, in degrees.
        If it is not a multiple of 90°, then the rotation can cause empty pixels of
        the mode's default color to be added for padding.
-    :param bool mirrored: Whether or not to mirror the image horizontally.
-    :returns PIL.Image: A Pillow image.
+    :param mirrored: Whether or not to mirror the image horizontally.
+    :returns: A Pillow image.
     """
     if (
         path.startswith("http://")
@@ -60,7 +71,7 @@ def open_image(path, mode="RGB", rotation_angle=0, mirrored=False):
         image = image.convert(mode)
 
     if mirrored:
-        image = image.transpose(Image.FLIP_LEFT_RIGHT)
+        image = image.transpose(Image.Transpose.FLIP_LEFT_RIGHT)
 
     if rotation_angle:
         image = image.rotate(-rotation_angle, expand=True)
@@ -68,12 +79,12 @@ def open_image(path, mode="RGB", rotation_angle=0, mirrored=False):
     return image
 
 
-def download_image(url):
+def download_image(url: str) -> Image:
     """
     Download an image and open it with Pillow.
 
-    :param url str: URL of the image.
-    :returns PIL.Image: A Pillow image.
+    :param url: URL of the image.
+    :returns: A Pillow image.
     """
     assert url.startswith("http"), "Image URL must be HTTP(S)"
 
@@ -102,19 +113,20 @@ def download_image(url):
     # Preprocess the image and prepare it for classification
     image = Image.open(BytesIO(resp.content))
     logger.info(
-        "Downloaded image {} - size={}x{}".format(url, image.size[0], image.size[1])
+        "Downloaded image {} - size={}x{} in {}".format(
+            url, image.size[0], image.size[1], resp.elapsed
+        )
     )
 
     return image
 
 
-def polygon_bounding_box(polygon):
+def polygon_bounding_box(polygon: List[List[Union[int, float]]]) -> BoundingBox:
     """
     Compute the rectangle bounding box of a polygon.
 
     :param polygon: Polygon to get the bounding box of.
-    :type polygon: list(list(int or float))
-    :returns BoundingBox: Bounding box of this polygon.
+    :returns: Bounding box of this polygon.
     """
     x_coords, y_coords = zip(*polygon)
     x, y = min(x_coords), min(y_coords)
@@ -142,12 +154,12 @@ def _retried_request(url):
     return resp
 
 
-def download_tiles(url):
+def download_tiles(url: str) -> Image:
     """
     Reconstruct a full IIIF image on servers that cannot serve the full-sized image, using tiles.
 
-    :param str url: URL of the image.
-    :returns PIL.Image: A Pillow image.
+    :param url: URL of the image.
+    :returns: A Pillow image.
     """
     if not url.endswith("/"):
         url += "/"
@@ -215,19 +227,19 @@ def download_tiles(url):
     return full_image
 
 
-def trim_polygon(polygon, image_width: int, image_height: int):
+def trim_polygon(
+    polygon: List[List[int]], image_width: int, image_height: int
+) -> List[List[int]]:
     """
     Trim a polygon to an image's boundaries, with non-negative coordinates.
 
     :param polygon: A polygon to trim.
-    :type: list(list(int or float) or tuple(int or float)) or tuple(tuple(int or float) or list(int or float))
-    :param image_width int: Width of the image.
-    :param image_height int: Height of the image.
+    :param image_width: Width of the image.
+    :param image_height: Height of the image.
     :returns: A polygon trimmed to the image's bounds.
        Some points may appear as missing, as the trimming can deduplicate points.
        The first and last point are always equal, to reproduce the behavior
        of the Arkindex backend.
-    :rtype: list(list(int or float))
     :raises AssertionError: When argument types are invalid or when the trimmed polygon
        is entirely outside of the image's bounds.
     """
@@ -268,23 +280,28 @@ def trim_polygon(polygon, image_width: int, image_height: int):
     return updated_polygon
 
 
-def revert_orientation(element, polygon):
+def revert_orientation(
+    element: Union["Element", "CachedElement"],
+    polygon: List[List[Union[int, float]]],
+    reverse: Optional[bool] = False,
+) -> List[List[int]]:
     """
     Update the coordinates of the polygon of a child element based on the orientation of
     its parent.
 
     This method should be called before sending any polygon to Arkindex, to undo the possible
-    orientation applied by :meth:`Element.open_image`.
+    orientation applied by [arkindex_worker.models.Element.open_image][].
+
+    In some cases, we want to apply the parent's orientation on the child's polygon instead. This is done
+    by enabling `reverse=True`.
 
     :param element: Parent element.
-    :type element: Element or CachedElement
     :param polygon: Polygon corresponding to the child element.
-    :type polygon: list(list(int or float))
+    :param reverse: Whether we should revert or apply the parent's orientation.
     :return: A polygon with updated coordinates.
-    :rtype: list(list(int))
     """
-    from arkindex_worker.models import Element
     from arkindex_worker.cache import CachedElement
+    from arkindex_worker.models import Element
 
     assert element and isinstance(
         element, (Element, CachedElement)
@@ -292,6 +309,7 @@ def revert_orientation(element, polygon):
     assert polygon and isinstance(
         polygon, list
     ), "polygon shouldn't be null and should be a list"
+    assert isinstance(reverse, bool), "Reverse should be a bool"
     # Rotating with Pillow can cause it to move the image around, as the image cannot have negative coordinates
     # and must be a rectangle.  This means the origin point of any coordinates from an image is invalid, and the
     # center of the bounding box of the rotated image is different from the center of the element's bounding box.
@@ -320,13 +338,24 @@ def revert_orientation(element, polygon):
 
     ring = LinearRing(polygon)
 
-    # First undo the negative coordinates offset, since this is the last step of the original rotation
-    ring = translate(ring, xoff=offset_x, yoff=offset_y)
-
-    if element.rotation_angle:
-        ring = rotate(ring, -element.rotation_angle, origin=origin)
-
-    if element.mirrored:
-        ring = scale(ring, xfact=-1, origin=origin)
+    if reverse:
+        # Apply the parent's orientation on the child's polygon
+        # Apply mirroring
+        if element.mirrored:
+            ring = scale(ring, xfact=-1, origin=origin)
+        # Apply rotation
+        if element.rotation_angle:
+            ring = rotate(ring, element.rotation_angle, origin=origin)
+        # At last translate coordinates offset
+        ring = translate(ring, xoff=-offset_x, yoff=-offset_y)
+    else:
+        # First undo the negative coordinates offset, since this is the last step of the original transformation
+        ring = translate(ring, xoff=offset_x, yoff=offset_y)
+        # Revert any rotation
+        if element.rotation_angle:
+            ring = rotate(ring, -element.rotation_angle, origin=origin)
+        # Revert any mirroring
+        if element.mirrored:
+            ring = scale(ring, xfact=-1, origin=origin)
 
     return [[int(x), int(y)] for x, y in ring.coords]
