@@ -5,12 +5,12 @@ Wrappers around API results to provide more convenient attribute access and IIIF
 
 import tempfile
 from contextlib import contextmanager
-from typing import Optional
+from typing import Generator, List, Optional
 
+from PIL import Image
 from requests import HTTPError
 
 from arkindex_worker import logger
-from arkindex_worker.image import download_tiles, open_image, polygon_bounding_box
 
 
 class MagicDict(dict):
@@ -63,7 +63,12 @@ class Element(MagicDict):
     Describes an Arkindex element.
     """
 
-    def resize_zone_url(self, size="full"):
+    def resize_zone_url(self, size: str = "full") -> str:
+        """
+        Compute the URL of the image corresponding to the size
+        :param size: Requested size
+        :return: The URL corresponding to the size
+        """
         if size == "full":
             return self.zone.url
         else:
@@ -71,13 +76,12 @@ class Element(MagicDict):
             parts[-3] = size
             return "/".join(parts)
 
-    def image_url(self, size="full") -> Optional[str]:
+    def image_url(self, size: str = "full") -> Optional[str]:
         """
         Build an URL to access the image.
         When possible, will return the S3 URL for images, so an ML worker can bypass IIIF servers.
-        :param str size: Subresolution of the image, following the syntax of the IIIF resize parameter.
+        :param size: Subresolution of the image, following the syntax of the IIIF resize parameter.
         :returns: An URL to the image, or None if the element does not have an image.
-        :rtype: str or None
         """
         if not self.get("zone"):
             return
@@ -89,12 +93,27 @@ class Element(MagicDict):
             url += "/"
         return "{}full/{}/0/default.jpg".format(url, size)
 
+    @property
+    def polygon(self) -> List[float]:
+        """
+        Access an Element's polygon.
+        This is a shortcut to an Element's polygon, normally accessed via
+        its zone field via `zone.polygon`. This is mostly done
+        to facilitate access to this important field by matching
+        the [CachedElement][arkindex_worker.cache.CachedElement].polygon field.
+        """
+        if not self.get("zone"):
+            raise ValueError("Element {} has no zone".format(self.id))
+        return self.zone.polygon
+
     @property
     def requires_tiles(self) -> bool:
         """
-        :return bool: Whether or not downloading and combining IIIF tiles will be necessary
+        :returns: Whether or not downloading and combining IIIF tiles will be necessary
            to retrieve this element's image. Will be False if the element has no image.
         """
+        from arkindex_worker.image import polygon_bounding_box
+
         if not self.get("zone") or self.zone.image.get("s3_url"):
             return False
         max_width = self.zone.image.server.max_width or float("inf")
@@ -102,7 +121,13 @@ class Element(MagicDict):
         bounding_box = polygon_bounding_box(self.zone.polygon)
         return bounding_box.width > max_width or bounding_box.height > max_height
 
-    def open_image(self, *args, max_size=None, use_full_image=False, **kwargs):
+    def open_image(
+        self,
+        *args,
+        max_size: Optional[int] = None,
+        use_full_image: Optional[bool] = False,
+        **kwargs
+    ) -> Image:
         """
         Open this element's image using Pillow, rotating and mirroring it according
         to the ``rotation_angle`` and ``mirrored`` attributes.
@@ -111,12 +136,12 @@ class Element(MagicDict):
         to bypass IIIF servers, the image will be cropped to the rectangle bounding box
         of the ``zone.polygon`` attribute.
 
-        .. warning::
-
+        Warns:
+        ----
            This method implicitly applies the element's orientation to the image.
 
            If your process uses the returned image to find more polygons and send them
-           back to Arkindex, use the :meth:`arkindex_worker.image.revert_orientation`
+           back to Arkindex, use the [arkindex_worker.image.revert_orientation][]
            helper to undo the orientation on all polygons before sending them, as the
            Arkindex API expects unoriented polygons.
 
@@ -125,19 +150,24 @@ class Element(MagicDict):
 
 
         :param max_size: The maximum size of the requested image.
-        :type max_size: int or None
-        :param bool use_full_image: Ignore the ``zone.polygon`` and always
+        :param use_full_image: Ignore the ``zone.polygon`` and always
            retrieve the image without cropping.
-        :param \\*args: Positional arguments passed to :meth:`arkindex_worker.image.open_image`.
-        :param \\**kwargs: Keyword arguments passed to :meth:`arkindex_worker.image.open_image`.
+        :param *args: Positional arguments passed to [arkindex_worker.image.open_image][].
+        :param **kwargs: Keyword arguments passed to [arkindex_worker.image.open_image][].
         :raises ValueError: When the element does not have an image.
         :raises NotImplementedError: When the ``max_size`` parameter is set,
            but the IIIF server's configuration requires downloading and combining tiles
            to retrieve the image.
         :raises NotImplementedError: When an S3 URL has been used to download the image,
            but the URL has expired. Re-fetching the URL automatically is not supported.
-        :return PIL.Image: A Pillow image.
+        :return: A Pillow image.
         """
+        from arkindex_worker.image import (
+            download_tiles,
+            open_image,
+            polygon_bounding_box,
+        )
+
         if not self.get("zone"):
             raise ValueError("Element {} has no zone".format(self.id))
 
@@ -197,18 +227,25 @@ class Element(MagicDict):
             raise
 
     @contextmanager
-    def open_image_tempfile(self, format="jpeg", *args, **kwargs):
+    def open_image_tempfile(
+        self, format: Optional[str] = "jpeg", *args, **kwargs
+    ) -> Generator[tempfile.NamedTemporaryFile, None, None]:
         """
         Get the element's image as a temporary file stored on the disk.
-        To be used as a context manager::
+        To be used as a context manager.
 
-           with element.open_image_tempfile() as f:
-               ...
+        Example
+        ----
+        ```
+        with element.open_image_tempfile() as f:
+            ...
+        ```
 
-        :param format str: File format to use the store the image on the disk.
+        :param format: File format to use the store the image on the disk.
            Must be a format supported by Pillow.
-        :param \\*args: Positional arguments passed to :meth:`arkindex_worker.image.open_image`.
-        :param \\**kwargs: Keyword arguments passed to :meth:`arkindex_worker.image.open_image`.
+        :param *args: Positional arguments passed to [arkindex_worker.image.open_image][].
+        :param **kwargs: Keyword arguments passed to [arkindex_worker.image.open_image][].
+
         """
         with tempfile.NamedTemporaryFile() as f:
             self.open_image(*args, **kwargs).save(f, format=format)
@@ -220,3 +257,12 @@ class Element(MagicDict):
         else:
             type_name = str(self.type)
         return "{} {} ({})".format(type_name, self.name, self.id)
+
+
+class Transcription(MagicDict):
+    """
+    Describes an Arkindex element's transcription.
+    """
+
+    def __str__(self):
+        return "Transcription ({})".format(self.id)
