@@ -4,6 +4,7 @@ ElementsWorker methods for transcriptions.
 """
 
 from enum import Enum
+from typing import Dict, Iterable, List, Optional, Union
 
 from peewee import IntegrityError
 
@@ -40,28 +41,22 @@ class TextOrientation(Enum):
 
 
 class TranscriptionMixin(object):
-    """
-    Mixin for the :class:`ElementsWorker` to provide ``Transcription`` helpers.
-    """
-
     def create_transcription(
         self,
-        element,
-        text,
-        confidence,
-        orientation=TextOrientation.HorizontalLeftToRight,
-    ):
+        element: Union[Element, CachedElement],
+        text: str,
+        confidence: float,
+        orientation: TextOrientation = TextOrientation.HorizontalLeftToRight,
+    ) -> Optional[Dict[str, Union[str, float]]]:
         """
         Create a transcription on the given element through the API.
 
         :param element: Element to create a transcription on.
-        :type element: Element or CachedElement
-        :param text str: Text of the transcription.
-        :param confidence float: Confidence score, between 0 and 1.
-        :param orientation TextOrientation: Orientation of the transcription's text.
+        :param text: Text of the transcription.
+        :param confidence: Confidence score, between 0 and 1.
+        :param orientation: Orientation of the transcription's text.
         :returns: A dict as returned by the ``CreateTranscription`` API endpoint,
            or None if the worker is in read-only mode.
-        :rtype: Dict[str, Union[str, float]] or None
         """
         assert element and isinstance(
             element, (Element, CachedElement)
@@ -87,7 +82,7 @@ class TranscriptionMixin(object):
             id=element.id,
             body={
                 "text": text,
-                "worker_version": self.worker_version_id,
+                "worker_run_id": self.worker_run_id,
                 "confidence": confidence,
                 "orientation": orientation.value,
             },
@@ -105,7 +100,7 @@ class TranscriptionMixin(object):
                         "text": created["text"],
                         "confidence": created["confidence"],
                         "orientation": created["orientation"],
-                        "worker_version_id": self.worker_version_id,
+                        "worker_run_id": self.worker_run_id,
                     }
                 ]
                 CachedTranscription.insert_many(to_insert).execute()
@@ -116,21 +111,24 @@ class TranscriptionMixin(object):
 
         return created
 
-    def create_transcriptions(self, transcriptions):
+    def create_transcriptions(
+        self,
+        transcriptions: List[Dict[str, Union[str, float, Optional[TextOrientation]]]],
+    ) -> List[Dict[str, Union[str, float]]]:
         """
         Create multiple transcriptions at once on existing elements through the API,
-        and creates :class:`CachedTranscription` instances if cache support is enabled.
+        and creates [CachedTranscription][arkindex_worker.cache.CachedTranscription] instances if cache support is enabled.
 
         :param transcriptions: A list of dicts representing a transcription each, with the following keys:
 
-           element_id (str)
-              Required. UUID of the element to create this transcription on.
-           text (str)
-              Required. Text of the transcription.
-           confidence (float)
-              Required. Confidence score between 0 and 1.
-           orientation (:class:`TextOrientation`)
-              Optional. Orientation of the transcription's text.
+            element_id (str)
+                Required. UUID of the element to create this transcription on.
+            text (str)
+                Required. Text of the transcription.
+            confidence (float)
+                Required. Confidence score between 0 and 1.
+            orientation (TextOrientation)
+                Optional. Orientation of the transcription's text.
 
         :returns: A list of dicts as returned in the ``transcriptions`` field by the ``CreateTranscriptions`` API endpoint.
         """
@@ -172,7 +170,7 @@ class TranscriptionMixin(object):
         created_trs = self.request(
             "CreateTranscriptions",
             body={
-                "worker_version": self.worker_version_id,
+                "worker_run_id": self.worker_run_id,
                 "transcriptions": transcriptions_payload,
             },
         )["transcriptions"]
@@ -190,7 +188,7 @@ class TranscriptionMixin(object):
                         "text": created_tr["text"],
                         "confidence": created_tr["confidence"],
                         "orientation": created_tr["orientation"],
-                        "worker_version_id": self.worker_version_id,
+                        "worker_run_id": self.worker_run_id,
                     }
                     for created_tr in created_trs
                 ]
@@ -202,23 +200,27 @@ class TranscriptionMixin(object):
 
         return created_trs
 
-    def create_element_transcriptions(self, element, sub_element_type, transcriptions):
+    def create_element_transcriptions(
+        self,
+        element: Union[Element, CachedElement],
+        sub_element_type: str,
+        transcriptions: List[Dict[str, Union[str, float]]],
+    ) -> Dict[str, Union[str, bool]]:
         """
         Create multiple elements and transcriptions at once on a single parent element through the API.
 
         :param element: Element to create elements and transcriptions on.
-        :type element: Element or CachedElement
-        :param str sub_element_type: Slug of the element type to use for the new elements.
+        :param sub_element_type: Slug of the element type to use for the new elements.
         :param transcriptions: A list of dicts representing an element and transcription each, with the following keys:
 
-           polygon (list(list(int or float)))
-              Required. Polygon of the element.
-           text (str)
-              Required. Text of the transcription.
-           confidence (float)
-              Required. Confidence score between 0 and 1.
-           orientation (:class:`TextOrientation`)
-              Optional. Orientation of the transcription's text.
+            polygon (list(list(int or float)))
+                Required. Polygon of the element.
+            text (str)
+                Required. Text of the transcription.
+            confidence (float)
+                Required. Confidence score between 0 and 1.
+            orientation ([TextOrientation][arkindex_worker.worker.transcription.TextOrientation])
+                Optional. Orientation of the transcription's text.
 
         :returns: A list of dicts as returned by the ``CreateElementTranscriptions`` API endpoint.
         """
@@ -281,7 +283,7 @@ class TranscriptionMixin(object):
             id=element.id,
             body={
                 "element_type": sub_element_type,
-                "worker_version": self.worker_version_id,
+                "worker_run_id": self.worker_run_id,
                 "transcriptions": transcriptions_payload,
                 "return_elements": True,
             },
@@ -318,7 +320,7 @@ class TranscriptionMixin(object):
                                 "type": sub_element_type,
                                 "image_id": element.image_id,
                                 "polygon": transcription["polygon"],
-                                "worker_version_id": self.worker_version_id,
+                                "worker_run_id": self.worker_run_id,
                             }
                         )
 
@@ -333,7 +335,7 @@ class TranscriptionMixin(object):
                         "orientation": transcription.get(
                             "orientation", TextOrientation.HorizontalLeftToRight
                         ).value,
-                        "worker_version_id": self.worker_version_id,
+                        "worker_run_id": self.worker_run_id,
                     }
                 )
 
@@ -348,22 +350,21 @@ class TranscriptionMixin(object):
         return annotations
 
     def list_transcriptions(
-        self, element, element_type=None, recursive=None, worker_version=None
-    ):
+        self,
+        element: Union[Element, CachedElement],
+        element_type: Optional[str] = None,
+        recursive: Optional[bool] = None,
+        worker_version: Optional[Union[str, bool]] = None,
+    ) -> Union[Iterable[dict], Iterable[CachedTranscription]]:
         """
         List transcriptions on an element.
 
         :param element: The element to list transcriptions on.
-        :type element: Element or CachedElement
         :param element_type: Restrict to transcriptions whose elements have an element type with this slug.
-        :type element_type: Optional[str]
         :param recursive: Include transcriptions of any descendant of this element, recursively.
-        :type recursive: Optional[bool]
-        :param worker_version: Restrict to transcriptions created by a worker version with this UUID.
-        :type worker_version: Optional[str]
+        :param worker_version: Restrict to transcriptions created by a worker version with this UUID. Set to False to look for manually created transcriptions.
         :returns: An iterable of dicts representing each transcription,
            or an iterable of CachedTranscription when cache support is enabled.
-        :rtype: Iterable[dict] or Iterable[CachedTranscription]
         """
         assert element and isinstance(
             element, (Element, CachedElement)
@@ -375,10 +376,14 @@ class TranscriptionMixin(object):
         if recursive is not None:
             assert isinstance(recursive, bool), "recursive should be of type bool"
             query_params["recursive"] = recursive
-        if worker_version:
+        if worker_version is not None:
             assert isinstance(
-                worker_version, str
-            ), "worker_version should be of type str"
+                worker_version, (str, bool)
+            ), "worker_version should be of type str or bool"
+            if isinstance(worker_version, bool):
+                assert (
+                    worker_version is False
+                ), "if of type bool, worker_version can only be set to False"
             query_params["worker_version"] = worker_version
 
         if self.use_cache:
@@ -409,9 +414,11 @@ class TranscriptionMixin(object):
                 if element_type:
                     transcriptions = transcriptions.where(cte.c.type == element_type)
 
-            if worker_version:
+            if worker_version is not None:
+                # If worker_version=False, filter by manual worker_version e.g. None
+                worker_version_id = worker_version if worker_version else None
                 transcriptions = transcriptions.where(
-                    CachedTranscription.worker_version_id == worker_version
+                    CachedTranscription.worker_version_id == worker_version_id
                 )
         else:
             transcriptions = self.api_client.paginate(
